@@ -1,8 +1,18 @@
+=head1 NAME
+
+API::Instagram - OO Interface to Instagram REST API
+
+=for HTML <a href="https://travis-ci.org/gabrielmad/API-Instagram"><img src="https://travis-ci.org/gabrielmad/API-Instagram.svg?branch=build%2Fmaster"></a>
+
+=head1 VERSION
+
+version 0.004
+
+=cut
+
 package API::Instagram;
 
-# ABSTRACT: OO Interface to Instagram REST API
-
-our $VERSION = '0.005.1';
+our $VERSION = '0.004';
 
 use Moo;
 
@@ -13,7 +23,6 @@ use warnings;
 use URI;
 use JSON;
 use LWP::UserAgent;
-use LWP::Protocol::https;
 # use LWP::Protocol::Net::Curl;
 
 use API::Instagram::User;
@@ -44,6 +53,109 @@ has _authorize_url    => ( is => 'ro', default => sub { 'https://api.instagram.c
 has _access_token_url => ( is => 'ro', default => sub { 'https://api.instagram.com/oauth/access_token' } );
 
 
+=head1 SYNOPSIS
+
+	use API::Instagram;
+
+	my $instagram = API::Instagram->new({
+			client_id   	=> $client_id,
+			client_secret	=> $client_secret,
+			redirect_uri	=> 'http://localhost',
+	});
+
+	# Authenticated user feed
+	my $my_user = $instagram->user;
+	my $feed    = $my_user->feed( count => 5 );
+
+	for my $media ( @$feed ) {
+
+		printf "Caption: %s\n", $media->caption;
+		printf "Posted by %s at %s (%d likes)\n\n", $media->user->username, $media->created_time, $media->likes;
+
+	}
+
+
+=head1 DESCRIPTION
+
+This module implements an OO interface to Instagram REST API.
+
+
+=head2 Authentication
+
+Instagram API uses the OAuth2 for authentication, requering a C<client_id> and
+C<client_secret>. See L<http://instagr.am/developer/register/> for details.
+
+=head3 Authorize
+
+Get the AUTH URL to authenticate.
+
+	use API::Instagram;
+
+	my $instagram = API::Instagram->new({
+			client_id		=> 'xxxxxxxxxx',
+			client_secret	=> 'xxxxxxxxxx',
+			redirect_uri	=> 'http://localhost',
+			scope           => 'basic',
+			response_type   => 'code',
+			granty_type     => 'authorization_code',
+	});
+
+	print $instagram->get_auth_url;
+
+
+=head3 Authenticate
+
+After authorization, Instagram will redirected the user to the URL in
+C<redirect_uri> with a code as an URL query parameter. This code is needed
+to obtain an acess token.
+
+	$instagram->set_code( $code );
+	my $access_token = $instagram->get_access_token;
+
+=head3 Request
+
+With the access token its possible to do Instagram API requests using the
+authenticated user credentials.
+
+	$instagram->access_token( $access_token );
+	my $me = $instagram->get_user;
+	print $me->full_name;
+
+
+=head1 METHODS
+
+=head2 new
+
+	my $instagram = API::Instagram->new({
+			client_id   	=> $client_id,
+			client_secret	=> $client_secret,
+			redirect_uri	=> 'http://localhost',
+			scope           => 'basic',
+			response_type   => 'code',
+			granty_type     => 'authorization_code',
+			no_cache        => 1,
+	});
+
+Returns an L<API::Instagram> object.
+
+Set C<client_id>, C<client_secret> and C<redirect_uri> with the ones registered
+to your application. See L<http://instagram.com/developer/clients/manage/>.
+
+C<scope> is the scope of access. See L<http://instagram.com/developer/authentication/#scope>.
+
+C<response_type> and C<granty_type> do no vary. See L<http://instagram.com/developer/authentication/>.
+
+By default, L<API::Instagram> caches created objects to avoid duplications. You can disable
+this feature setting a true value to C<no_chace> parameter.
+
+=head2 get_auth_url
+
+	my $auth_url = $instagram->get_auth_url;
+	print $auth_url;
+
+Returns an Instagram authorization URL.
+
+=cut
 sub get_auth_url { 
 	my $self = shift;
 
@@ -60,6 +172,19 @@ sub get_auth_url {
 }
 
 
+=head2 get_access_token
+
+	my $access_token = $instagram->get_access_token;
+
+	or
+
+	my ( $access_token, $auth_user ) = $instagram->get_access_token;
+
+Returns the access token string if the context is looking for a scalar, or an
+array containing the access token string and the authenticated user
+L<API::Instagram::User> object if looking for a list value.
+
+=cut
 sub get_access_token {
 	my $self = shift;
 
@@ -78,15 +203,50 @@ sub get_access_token {
 }
 
 
+=head2 media
+
+	my $media = $instagram->media( $media_id );
+	say $media->type;
+
+Get information about a media object. Returns an L<API::Instagram::Media> object.
+
+=cut
 sub media { shift->_get_obj( 'media', '/medias', 'medias', 'id', shift ) }
 
 
+=head2 user
+
+	my $me = $instagram->user; # Authenticated user
+	say $me->username;
+
+	my $user = $instagram->user( $user_id );
+	say $user->full_name;
+
+Get information about an user. Returns an L<API::Instagram::User> object.
+
+=cut
 sub user { shift->_get_obj( 'user', '/users', 'users', 'id', shift || 'self' ) }
 
 
+=head2 location
+
+	my $location = $instagram->location( $location_id );
+	say $location->name;
+
+Get information about a location. Returns an L<API::Instagram::Location> object.
+
+=cut
 sub location { shift->_get_obj( 'location', '/locations', 'locations', 'id', shift ) }
 
 
+=head2 tag
+
+	my $tag = $instagram->tag('perl');
+	say $tag->media_count;
+
+Get information about a tag. Returns an L<API::Instagram::Tag> object.
+
+=cut
 sub tag { shift->_get_obj( 'tag', '/tags', 'tags', 'name', shift ) }
 
 
@@ -205,177 +365,36 @@ sub _delete_cache {
 	delete $self->_obj_cache->{$cache}->{$id};
 }
 
-
 1;
 
-__END__
+=head1 BUGS
 
-=pod
+Please report me bugs if you find any.
 
-=encoding UTF-8
+L<http://github.com/gabrielmad/API-Instagram/issues>
 
-=head1 NAME
 
-API::Instagram - OO Interface to Instagram REST API
+=head1 SEE ALSO
 
-=for Pod::Coverage client_id client_secret grant_type no_cache redirect_uri response_type scope
+=over
 
-=for HTML <a href="https://travis-ci.org/gabrielmad/API-Instagram"><img src="https://travis-ci.org/gabrielmad/API-Instagram.svg?branch=build%2Fmaster"></a>
+=item *
 
-=head1 VERSION
+L<WebService::Instagram>
 
-version 0.005.1
-
-=head1 SYNOPSIS
-
-	use API::Instagram;
-
-	my $instagram = API::Instagram->new({
-			client_id   	=> $client_id,
-			client_secret	=> $client_secret,
-			redirect_uri	=> 'http://localhost',
-	});
-
-	# Authenticated user feed
-	my $my_user = $instagram->user;
-	my $feed    = $my_user->feed( count => 5 );
-
-	for my $media ( @$feed ) {
-
-		printf "Caption: %s\n", $media->caption;
-		printf "Posted by %s at %s (%d likes)\n\n", $media->user->username, $media->created_time, $media->likes;
-
-	}
-
-=head1 DESCRIPTION
-
-This module implements an OO interface to Instagram REST API.
-
-=head2 Authentication
-
-Instagram API uses the OAuth2 for authentication, requering a C<client_id> and
-C<client_secret>. See L<http://instagr.am/developer/register/> for details.
-
-=head3 Authorize
-
-Get the AUTH URL to authenticate.
-
-	use API::Instagram;
-
-	my $instagram = API::Instagram->new({
-			client_id		=> 'xxxxxxxxxx',
-			client_secret	=> 'xxxxxxxxxx',
-			redirect_uri	=> 'http://localhost',
-			scope           => 'basic',
-			response_type   => 'code',
-			granty_type     => 'authorization_code',
-	});
-
-	print $instagram->get_auth_url;
-
-=head3 Authenticate
-
-After authorization, Instagram will redirected the user to the URL in
-C<redirect_uri> with a code as an URL query parameter. This code is needed
-to obtain an acess token.
-
-	$instagram->code( $code );
-	my $access_token = $instagram->get_access_token;
-
-=head3 Request
-
-With the access token its possible to do Instagram API requests using the
-authenticated user credentials.
-
-	$instagram->access_token( $access_token );
-	my $me = $instagram->user;
-	print $me->full_name;
-
-=head1 METHODS
-
-=head2 new
-
-	my $instagram = API::Instagram->new({
-			client_id   	=> $client_id,
-			client_secret	=> $client_secret,
-			redirect_uri	=> 'http://localhost',
-			scope           => 'basic',
-			response_type   => 'code',
-			granty_type     => 'authorization_code',
-			no_cache        => 1,
-	});
-
-Returns an L<API::Instagram> object.
-
-Set C<client_id>, C<client_secret> and C<redirect_uri> with the ones registered
-to your application. See L<http://instagram.com/developer/clients/manage/>.
-
-C<scope> is the scope of access. See L<http://instagram.com/developer/authentication/#scope>.
-
-C<response_type> and C<granty_type> do no vary. See L<http://instagram.com/developer/authentication/>.
-
-By default, L<API::Instagram> caches created objects to avoid duplications. You can disable
-this feature setting a true value to C<no_chace> parameter.
-
-=head2 get_auth_url
-
-	my $auth_url = $instagram->get_auth_url;
-	print $auth_url;
-
-Returns an Instagram authorization URL.
-
-=head2 get_access_token
-
-	my $access_token = $instagram->get_access_token;
-
-	or
-
-	my ( $access_token, $auth_user ) = $instagram->get_access_token;
-
-Returns the access token string if the context is looking for a scalar, or an
-array containing the access token string and the authenticated user
-L<API::Instagram::User> object if looking for a list value.
-
-=head2 media
-
-	my $media = $instagram->media( $media_id );
-	say $media->type;
-
-Get information about a media object. Returns an L<API::Instagram::Media> object.
-
-=head2 user
-
-	my $me = $instagram->user; # Authenticated user
-	say $me->username;
-
-	my $user = $instagram->user( $user_id );
-	say $user->full_name;
-
-Get information about an user. Returns an L<API::Instagram::User> object.
-
-=head2 location
-
-	my $location = $instagram->location( $location_id );
-	say $location->name;
-
-Get information about a location. Returns an L<API::Instagram::Location> object.
-
-=head2 tag
-
-	my $tag = $instagram->tag('perl');
-	say $tag->media_count;
-
-Get information about a tag. Returns an L<API::Instagram::Tag> object.
+=back
 
 =head1 AUTHOR
 
-Gabriel Vieira <gabriel.vieira@gmail.com>
+Gabriel Vieira C<< <gabriel.vieira at gmail.com> >>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT
+ 
+Copyright 2013 - Tatsuhiko Miyagawa
 
-This software is copyright (c) 2014 by Gabriel Vieira.
+=head1 LICENSE AND COPYRIGHT
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+Copyright (c) 2014, Gabriel Vieira C<< <gabriel.vieira at gmail.com> >>. All rights reserved.
 
-=cut
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself. See L<perlartistic>.
